OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No faghet a iscriere in sa cartella \"config\"!",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma si preferis mantènnere s'archìviu config.php comente de letura isceti, cunfigura s'optzione \"config_is_read_only\" comente \"true\".",
    "See %s" : "Càstia %s",
    "Sample configuration detected" : "S'at agatadu una cunfiguratzione de esèmpiu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Est istadu iscobertu ca sa cunfiguratzione de esèmpiu est istada copiada. Custu podet blocare s'installatzione e no est suportadu. Leghe sa documentatzione in config.php antis de fàghere càmbios.",
    "The page could not be found on the server." : "Impossìbile agatare custa pàgina in su serbidore.",
    "Other activities" : "Àteras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Enterprise bundle" : "Pachete Enterprise",
    "Groupware bundle" : "Pachete Groupware",
    "Hub bundle" : "Pachete Hub",
    "Social sharing bundle" : "Pachete cumpartzidura Social ",
    "PHP %s or higher is required." : "Est rechèdidu PHP %s o superiore.",
    "PHP with a version lower than %s is required." : "Est rechèdidu unu PHP cun una versione minore de %s",
    "%sbit or higher PHP required." : "Est rechèdidu PHP de%s bit o superiore.",
    "The following architectures are supported: %s" : "Sunt suportadas custas architeturas: %s",
    "The following databases are supported: %s" : "Sunt suportadas custas bases de datos: %s",
    "The command line tool %s could not be found" : "No at fatu a agatare s'aina de cumandu de lìnia %s",
    "The library %s is not available." : "Sa libreria %s no est a disponimentu.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Est rechèdida una libreria %1$s cun una versione superiore a %2$s - versione a disponimentu %3$s. ",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Est rechèdida una libreria %1$s cun una versione inferiore a %2$s - versione a disponimentu %3$s. ",
    "The following platforms are supported: %s" : "Sunt suportadas custas prataformas: %s",
    "Server version %s or higher is required." : "Est rechèdidu sa versione de serbidore %s o superiore.",
    "Server version %s or lower is required." : "Est rechèdidu sa versione de serbidore %s o inferiore.",
    "Wiping of device %s has started" : "S'at cumintzadu sa cantzelladura de su dispositivu %s",
    "Wiping of device »%s« has started" : "S'at cumintzadu sa cantzelladura de su dispositivu »%s«",
    "»%s« started remote wipe" : "»%s« at cumintzadu sa cantzelladura de tesu",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Su dispositivu »%s« at cumintzadu su protzessu de cantzelladura de tesu. As a retzire un'àteru messàgiu de posta eletrònica cando su protzessu at a èssere acabbadu.",
    "Wiping of device %s has finished" : "Sa cantzelladura de su dispositivu %s est acabbada",
    "Wiping of device »%s« has finished" : "Sa cantzelladura de su dispositivu »%s« est acabbada",
    "»%s« finished remote wipe" : "»%s« at acabbadu sa cantzelladura de tesu",
    "Device or application »%s« has finished the remote wipe process." : "Su dispositivu o s'aplicatzione »%s« at acabbadu su protzessu de cantzelladura de tesu.",
    "Remote wipe started" : "Cantzelladura de tesu aviada",
    "A remote wipe was started on device %s" : "Una cantzelladura de tesu est cumintzada in su dispositivu %s",
    "Remote wipe finished" : "Cantzelladura de tesu acabbada",
    "The remote wipe on %s has finished" : "Sa cantzelladura de tesu in %s est acabbada",
    "Authentication" : "Autenticatzione",
    "Unknown filetype" : "Genia de archìviu disconnota",
    "Invalid image" : "Immàgine non bàlida",
    "Avatar image is not square" : "S'immàgine de s'avatar no est cuadrada",
    "Files" : "Archìvios",
    "View profile" : "Ammustra su profilu",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "today" : "oe",
    "tomorrow" : "cras",
    "yesterday" : "eris",
    "_in %n day_::_in %n days_" : ["tra %n dies","de immoe a %n dies"],
    "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
    "next month" : "su mese chi benit",
    "last month" : "su mese passadu",
    "_in %n month_::_in %n months_" : ["tra %n meses","de immoe a %n meses"],
    "_%n month ago_::_%n months ago_" : ["%n meses a oe","%n meses a oe"],
    "next year" : "s'annu chi benit",
    "last year" : "s'annu passadu",
    "_in %n year_::_in %n years_" : ["tra %n annos","de immoe a %n annos"],
    "_%n year ago_::_%n years ago_" : ["%n annos a oe","%n dies a oe"],
    "_in %n hour_::_in %n hours_" : ["tra %n oras","de immoe a %n oras"],
    "_%n hour ago_::_%n hours ago_" : ["%n oras a immoe","%n oras a immoe"],
    "_in %n minute_::_in %n minutes_" : ["%n meses","de immoe a %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minutos a immoe","%n minutos a immoe"],
    "in a few seconds" : "de immoe a pagos segundos",
    "seconds ago" : "segundos a immoe",
    "Empty file" : "Archìviu bòidu",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Su mòdulu cun ID: %s no esistit. Ativa·ddu in sa cunfiguratzione de s'aplicatzione o cuntata s'amministratzione.",
    "Dot files are not allowed" : "Is archìvios cun unu puntu a su cumintzu no sunt permìtidos",
    "File already exists" : "S'archìviu b'est giai",
    "Invalid path" : "Percursu non bàlidu",
    "Failed to create file from template" : "No at fatu a creare s'archìviu dae su modellu",
    "Templates" : "Modellos",
    "Filename contains at least one invalid character" : "Su nùmene de su documentu cuntenet a su mancu unu caràtere non vàlidu",
    "Empty filename is not allowed" : "Unu nùmene de archìviu bòidu no est permìtidu",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "No faghet a installare s'aplicatzione \"%s\"  ca no faghet a lèghere s'archìviu appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No faghet a installare s'aplicatzione \"%s\" ca no est cumpatìbile cun custa versione de su serbidore.",
    "__language_name__" : "sardu",
    "This is an automatically sent email, please do not reply." : "Custu est unu messàgiu de posta imbiadu in automàticu, non rispondas.",
    "Help & privacy" : "Agiudu e riservadesa",
    "Appearance and accessibility" : "Aspetu e atzessibilidade",
    "Apps" : "Aplicatziones",
    "Settings" : "Cunfiguratzione",
    "Log out" : "Essi·nche",
    "Accounts" : "Accounts",
    "Email" : "Posta eletrònica",
    "Phone" : "Telèfonu",
    "Twitter" : "Twitter",
    "Website" : "Situ ìnternet",
    "Address" : "Indiritzu",
    "Profile picture" : "Immàgine de profilu",
    "About" : "In contu de",
    "Display name" : "Ammustra nùmene",
    "Headline" : "Tìtulos",
    "Organization" : "Organizatzione",
    "Role" : "Faina",
    "Additional settings" : "Cunfiguratziones in agiunta",
    "You need to enter details of an existing account." : "Nche depes insertare is detàllios de unu contu chi b'est giai.",
    "Oracle connection could not be established" : "No at fatu a istabilire sa connessione Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "Pro su mellus resurtadu, cunsidera in càmbiu de impreare unu serbidore GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parit ca custa istàntzia %s est traballende in un'ambiente PHP a 32-bit e sa open_basedir est istada cunfigurada in php.ini. Custu at a causare problemas cun archìvios de prus de 4 GB e est iscussigiadu a forte.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Boga·nche sa cunfiguratzione open_basedir in su php.ini tuo o càmbia a su PHP a 64-bit.",
    "Set an admin password." : "Cunfigura una crae de amministratzione.",
    "Cannot create or write into the data directory %s" : "No faghet a creare o a iscriere a intro de sa cartella de datos %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Su motore de cumpartzidura %s depet cumpletare s'interfache OCP\\Share_Backend",
    "Sharing backend %s not found" : "Motore de cumpartzidura%s no agatadu",
    "Sharing backend for %s not found" : "Motore de cumpartzidura pro %s no agatadu",
    "%1$s via %2$s" : "%1$s cun %2$s",
    "Unknown share type" : "Genia de cumpartzidura disconnota",
    "Shared path must be either a file or a folder" : "Su percursu cumpartzidu depet èssere un'archìviu o una cartella",
    "You are not allowed to share %s" : "No tenes su permissu de cumpartzire %s",
    "Cannot increase permissions of %s" : "No faghet a crèschere is permissos de %s",
    "Files cannot be shared with delete permissions" : "No faghet a cumpartzire archìvios cun permissos de cantzelladura",
    "Files cannot be shared with create permissions" : "No faghet a cumpartzire archìvios cun permissos de creatzione",
    "Expiration date is in the past" : "Sa data de iscadèntzia est giai passada",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No faghet a impostare sa data de iscadèntzia a prus de %n die in su benidore","Impossìbile cunfigurare sa data de iscadèntzia a prus de %n dies in su benidore"],
    "Sharing is only allowed with group members" : "Sa cumpartzidura est permìtida isceti cun is partetzipantes de su grupu",
    "The requested share does not exist anymore" : "Sa cumpartzidura pedida no b'est prus",
    "Could not find category \"%s\"" : "No at fatu a agatare sa categoria \"%s\"",
    "Sunday" : "Domìnigu",
    "Monday" : "lunis",
    "Tuesday" : "Martis",
    "Wednesday" : "Mércuris",
    "Thursday" : "Giòbia",
    "Friday" : "Chenàbura",
    "Saturday" : "Sàbudu",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Gio.",
    "Fri." : "Che.",
    "Sat." : "Sàb.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Gi",
    "Fr" : "Ch",
    "Sa" : "Sa",
    "January" : "Ghennàrgiu",
    "February" : "Freàrgiu",
    "March" : "Martzu",
    "April" : "Abrile",
    "May" : "Maju",
    "June" : "Làmparas",
    "July" : "Mese de Trìulas/Argiolas",
    "August" : "Austu",
    "September" : "Cabudanni",
    "October" : "Mese de Ladàmini/ Santu Aine",
    "November" : "Sant'Andria",
    "December" : "Nadale",
    "Jan." : "Ghe.",
    "Feb." : "Fre.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Maj.",
    "Jun." : "Lam.",
    "Jul." : "Tri./Arg.",
    "Aug." : "Aus.",
    "Sep." : "Cab.",
    "Oct." : "Lad./SGa.",
    "Nov." : "SAnd.",
    "Dec." : "Nad.",
    "A valid password must be provided" : "Depes frunire una crae bàlida",
    "Login canceled by app" : "Atzessu annulladu dae s'aplicatzione",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non faghet a installare s'aplicatzione %1$s ca is dipendèntzias in fatu non sunt  satisfatos:%2$s",
    "a safe home for all your data" : "unu logu seguru pro totu is datos tuos",
    "Application is not enabled" : "S'aplicatzione no est ativada",
    "Authentication error" : "Errore de autenticatzione",
    "Token expired. Please reload page." : "Token iscadidu. Torra a carrigare sa pàgina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Perunu driver de base de datos (sqlite, mysql, or postgresql) installadu.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ma si preferis mantènnere s'archìviu config.php comente de letura isceti, cunfigura s'optzione \"config_is_read_only\" comente \"true\". Càstia %s",
    "PHP module %s not installed." : "Su mòdulu PHP %s no est installadu.",
    "Please ask your server administrator to install the module." : "Pedi a s'amministratzione de serbidore de installare su mòdulu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Sa cunfiguratzione PHP %s no est a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Assentende custa cunfiguratzione in php.ini at a torrare a fàghere traballare Nextcloud",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Paret che PHP siat cunfigurare pro nde bogare is blocos de documentatzione in lìnia. Custu at a impedire s'atzessu a medas aplicatziones printzipales.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Podet èssere causadu dae una memòria temporànea/atzeleradore cales Zend Opcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Is mòdulos PHP sunt istados installados, ma sunt ancora elencados comente mancantes?",
    "Please ask your server administrator to restart the web server." : "Pedi a s'amministratzione de su serbidore de torrare a aviare su serbidore ìnternet.",
    "Action \"%s\" not supported or implemented." : "S'atzione \"%s\" no est suportada o cumpletada.",
    "Authentication failed, wrong token or provider ID given" : "No at fatu a fàghere s'autenticatzione, token o ID de su frunidore isballiados",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Mancant paràmetros pro pòdere cumpletare sa rechesta. Paràmetros mancantes: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Su ID \"%1$s\" est giai impreadu dae su frunidore de sa federatzione de nue virtuale \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Su frunidore de sa federatzione de nue virtuale cun ID: \"%s\" no esistit.",
    "Could not obtain lock type %d on \"%s\"." : "No at fatu a otènnere su blocu de genia %d in \"%s\".",
    "Storage unauthorized. %s" : "Archiviatzione no autorizada. %s",
    "Storage incomplete configuration. %s" : "Cunfiguratzione de s'archiviatzione no cumpleta. %s",
    "Storage connection error. %s" : "Errore de connessione a s'archiviatzione. %s",
    "Storage is temporarily not available" : "S'archiviatzione no est disponìbile pro immoe.",
    "Storage connection timeout. %s" : "Tempus de connessione a s'archiviatzione iscadidu. %s",
    "Images" : "Immàgines",
    "Optical character recognition" : "Reconnoschimentu òticu de si caràteres",
    "Chat" : "Tzarrada",
    "Generate a headline" : "Gènera unu tìtulu",
    "Generates a possible headline for a text." : "Gènerat unu tìtulu possìbile pro unu testu.",
    "The original text to generate a headline for" : "Su testu originale pro su chi s'at a generare unu tìtulu",
    "The generated headline" : "Su tìtulu generadu",
    "Text" : "Testu",
    "Summary" : "Resumu",
    "Translate" : "Borta",
    "Result" : "Resurtadu",
    "Generate headline" : "Gènera unu tìtulu",
    "Organisation" : "Organizatzione"
},
"nplurals=2; plural=(n != 1);");
